/*
 * Fix search fields.
 * Copyright (c) 2018 University of California, San Diego.
 *
 * Dual licensed under the MIT and GPL licenses:
 *	http://www.opensource.org/licenses/mit-license.php
 *	http://www.gnu.org/licenses/gpl.html
 *
 * By default, for 'search' input fields Drupal:
 * - Disables browser-specific search styling.
 * - Does not set a search field's placeholder text.
 * - Does not include Safari's 'results' attribute.
 *
 * This script searches for all search fields and:
 * - Adds placeholder text 'Search...' if text hasn't been set.
 * - Adds the 'results' attribute if it hasn't been set.
 *
 * Search styling is handled by the theme's CSS.
 */
 
(function ($) {
	"use strict";

  $(document).ready( function() {
      $('input[type="search"]').each( function() {
        if (typeof $(this).attr('results') === 'undefined') {
          // For Safari, the presence of this field causes the search
          // field's magnifying glass icon to be shown. The attribute
          // has no effect on other browsers.
          $(this).attr('results', '');
        }

        if (typeof $(this).attr('placeholder') === 'undefined') {
          // For all browsers, placeholder text provides background
          // text pending user entry of search text. It also serves
          // to document what the input is for.
          $(this).attr('placeholder', 'Search...');
        }
      });
  });

})(jQuery);
